package de.hft.stuttgart.citydoctor2.connect.edge;



import de.hft.stuttgart.citydoctor2.connect.edge.CppReferenceHandlingBase;
import de.hft.stuttgart.citydoctor2.connect.edge.NativePointerCastException;

public class AutoProSettingsBool extends CppReferenceHandlingBase {
	private native long createCppClass(
			
				boolean useBool,
				boolean printBoolInfo,
				boolean exportIntermediateStages,
				boolean useMinkowski,
				boolean printMinkowskiInfo,
				double minkowksiCubeSize,
				boolean rotateMinkowskiCube
				
			)
			throws OutOfMemoryError;

	private native void disposeCppClass(long ptrToCppAutoPro)
			throws NativePointerCastException;

	private boolean useBool;	
	private boolean printBoolInfo;
	private boolean exportIntermediateStages;	
	private boolean useMinkowski;	
	private boolean printMinkowskiInfo;
	private double minkowskiCubeSize;
	private boolean rotateMinkowskiCube;


	public AutoProSettingsBool() {

		setUseBool(false);	
		setPrintBoolInfo(false);	
		setExportIntermediateStages(false);
		setUseMinkowski(false);	
		setPrintMinkowskiInfo(false);
		setMinkowskiCubeSize(2.2);
		setRotateMinkowskiCube(false);

	}

	/**
	 * Creates an C++ feature object
	 * 
	 * @throws IllegalStateException
	 *             Thrown if the encapsulated "long-Pointer" isn't 0
	 * @throws NativeOutOfMemoryException
	 *             If there is no more memory on the native side
	 * 
	 * @see {@link disposeCppObject}
	 * @see de.hft.stuttgart.citydoctor.connect.edGe.CppReferenceHandlingBase#createCppObject()
	 */
	public void createCppObject() throws IllegalStateException,
			OutOfMemoryError {
		if (0L != ptrToCppObject) {
			throw new IllegalStateException(
					"Can't create new C++ object, there is allready one!");
		}
		// Maybe an exception is thrown
		long tmpPointer = createCppClass(
				isUseBool(),
				isPrintBoolInfo(),
				isExportIntermediateStages(),
				isUseMinkowski(),
				isPrintMinkowskiInfo(),
				getMinkowskiCubeSize(),
				isRotateMinkowskiCube()
				);
		ptrToCppObject = tmpPointer;
	}

	@Override
	public void disposeCppObject() throws NativePointerCastException {
		if (0L != ptrToCppObject) {
			disposeCppClass(ptrToCppObject);
			ptrToCppObject = 0L;
		}
	}

	public void setUseBool(boolean useBool) {
		this.useBool = useBool;
	}

	public void setPrintBoolInfo(boolean printBoolInfo) {
		this.printBoolInfo = printBoolInfo;
	}	
	
	public void setExportIntermediateStages(boolean exportIntermediateStages) {
		this.exportIntermediateStages = exportIntermediateStages;
	}
	
	public void setUseMinkowski(boolean useMinkowski) {
		this.useMinkowski = useMinkowski;
	}

	public void setPrintMinkowskiInfo(boolean printMinkowskiInfo) {
		this.printMinkowskiInfo = printMinkowskiInfo;
	}

	public void setMinkowskiCubeSize(double minkowskiCubeSize) {
		this.minkowskiCubeSize = minkowskiCubeSize;
	}
	public void setRotateMinkowskiCube(boolean rotateMinkowskiCube) {
		this.rotateMinkowskiCube = rotateMinkowskiCube;
	}
	

	public boolean isUseBool() {
		return useBool;
	}	

	public boolean isPrintBoolInfo() {
		return printBoolInfo;
	}	
	

	public boolean isExportIntermediateStages() {
		return exportIntermediateStages;
	}	

	public boolean isUseMinkowski() {
		return useMinkowski;
	}	

	public boolean isPrintMinkowskiInfo() {
		return printMinkowskiInfo;
	}	

	public double getMinkowskiCubeSize() {
		return minkowskiCubeSize;
	}
	public boolean isRotateMinkowskiCube() {
		return rotateMinkowskiCube;
	}

}
