package de.hft.stuttgart.citydoctor2.ziploader;

import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParseException;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParser;
import de.hft.stuttgart.citydoctor2.parser.InvalidGmlFileException;
import de.hft.stuttgart.citydoctor2.parser.ParserConfiguration;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.util.zip.ZipEntry;

public class CityGmlZipEntry {

    private static final Logger logger = LogManager.getLogger(CityGmlZipEntry.class);


    private String fileName;
    private String archivePath;
    private CityDoctorModel model;

    private boolean erroneous = false;
    private boolean isLibraryObject = false;

    public static CityGmlZipEntry of(ZipEntry entry, ParserConfiguration config, String archivePath){
        CityGmlZipEntry cgzEntry = new CityGmlZipEntry();
        cgzEntry.fileName = entry.getName();
        cgzEntry.archivePath = archivePath;
        try {
            cgzEntry.model = CityGmlParser.parseCityGmlFile(entry.getName(), config);
        }
        catch (CityGmlParseException | InvalidGmlFileException e) {
            logger.error(e);
            cgzEntry.erroneous = true;
        }
        return cgzEntry;
    }

    public void setIsLibraryObject(boolean isLibraryObject) {
        this.isLibraryObject = isLibraryObject;
    }

    public String getFileName() {
        return fileName;
    }

    public String getArchivePath() {
        return archivePath;
    }

    public CityDoctorModel getModel() {
        return model;
    }

    public boolean isLibraryObject() {
        return isLibraryObject;
    }

    public boolean isErroneous() {
        return erroneous;
    }
}
